@@ -1,5 +1,9 @@
 import math
 from .settings import *
+from shapely import geometry
+
+default_bounds = {'minlat':-90.0, 'minlon':-180.0, 'maxlat':90.0, 'maxlon':180.0}
+
 
 def getDistanceFromCoord(lon1, lat1, lon2, lat2):
     # return km
@@ -12,6 +16,20 @@ def getDistanceFromCoord(lon1, lat1, lon2, lat2):
     return c * r
 
 
+def getLineFromRefNodes(ref_node_list):
+    if len(ref_node_list) < 2: return None
+    point_list = [node.geometry for node in ref_node_list]
+    line = geometry.LineString(point_list)
+    return line
+
+
+def getPolygonFromRefNodes(ref_node_list):
+    if len(ref_node_list) < 3: return None
+    point_list = [node.geometry for node in ref_node_list]
+    poly = geometry.Polygon(point_list)
+    return poly
+
+
 def printlog(msg,log_level='info'):
     if not print_log: return
 
